@@ -126,7 +126,7 @@
 #' (in big endian order).  The `TreeNumber` object has attributes
 #' `nTip` and `tip.label`.
 #' @export
-as.TreeNumber <- function(x, ...) UseMethod('as.TreeNumber')
+as.TreeNumber <- function(x, ...) UseMethod("as.TreeNumber")
 
 .TT_MAX_TIP <- 19L
 # Calculate with:
@@ -153,7 +153,7 @@ as.TreeNumber.phylo <- function(x, ...) {
   structure(.Int64(edge_to_num(edge[, 1], edge[, 2], nTip)),
             nTip = nTip,
             tip.label = TipLabels(x),
-            class = c('TreeNumber', 'integer64'))
+            class = c("TreeNumber", "integer64"))
 }
 
 #' @rdname TreeNumber
@@ -168,7 +168,7 @@ as.TreeNumber.character <- function(x, nTip, tipLabels = TipLabels(nTip), ...) {
   structure(as.integer64(x),
             nTip = nTip,
             tip.label = tipLabels,
-            class = c('TreeNumber', 'integer64'))
+            class = c("TreeNumber", "integer64"))
 }
 
 #' @rdname TreeNumber
@@ -262,8 +262,8 @@ as.MixedBase.numeric <- function(x, tipLabels = NULL, ...) {
 #'
 #' @importFrom ape as.phylo
 #' @export
-as.phylo.numeric <- function(x, nTip = attr(x, 'nTip'),
-                              tipLabels = attr(x, 'tip.label'), ...) {
+as.phylo.numeric <- function(x, nTip = attr(x, "nTip"),
+                              tipLabels = attr(x, "tip.label"), ...) {
   if (is.null(nTip)) {
     if (is.null(tipLabels)) {
       stop("Either nTip or tipLabels must be specified.")
@@ -272,30 +272,30 @@ as.phylo.numeric <- function(x, nTip = attr(x, 'nTip'),
     }
   }
   if (is.null(tipLabels)) {
-    tipLabels <- paste0('t', seq_len(nTip))
+    tipLabels <- paste0("t", seq_len(nTip))
   }
   if (nTip == 1) {
     SingleTaxonTree(tipLabels)
   } else {
     if (length(x) > 1) {
       structure(lapply(x, as.phylo.numeric, nTip = nTip, tipLabels = tipLabels),
-                tip.label = tipLabels, class = 'multiPhylo')
+                tip.label = tipLabels, class = "multiPhylo")
     } else {
       edge <- RenumberEdges(num_to_parent(.Int64.to.C(x), nTip),
                             seq_len(nTip + nTip - 2L))
       structure(list(edge = do.call(cbind, edge),
                      tip.label = tipLabels,
                      Nnode = nTip - 1L),
-                order = 'preorder',
-                class = 'phylo')
+                order = "preorder",
+                class = "phylo")
     }
   }
 }
 
 # Copied from as.phylo.numeric except if length > 1
 #' @export
-as.phylo.integer64 <- function(x, nTip = attr(x, 'nTip'),
-                                tipLabels = attr(x, 'tip.label'), ...) {
+as.phylo.integer64 <- function(x, nTip = attr(x, "nTip"),
+                                tipLabels = attr(x, "tip.label"), ...) {
   if (is.null(nTip)) {
     if (is.null(tipLabels)) {
       stop("Either nTip or tipLabels must be specified.")
@@ -304,25 +304,25 @@ as.phylo.integer64 <- function(x, nTip = attr(x, 'nTip'),
     }
   }
   if (is.null(tipLabels)) {
-    tipLabels <- paste0('t', seq_len(nTip))
+    tipLabels <- paste0("t", seq_len(nTip))
   }
   if (nTip == 1) {
     SingleTaxonTree(tipLabels)
   } else {
     if (length(x) > 1) {
-      ret <- vector('list', length(x))
+      ret <- vector("list", length(x))
       for (i in seq_along(x)) {
         ret[[i]] <- as.phylo(x[i], nTip = nTip, tipLabels = tipLabels)
       }
-      ret <- structure(ret, tip.label = tipLabels, class = 'multiPhylo')
+      ret <- structure(ret, tip.label = tipLabels, class = "multiPhylo")
     } else {
       edge <- RenumberEdges(num_to_parent(.Int64.to.C(x), nTip),
                             seq_len(nTip + nTip - 2L))
       structure(list(edge = do.call(cbind, edge),
                      tip.label = tipLabels,
                      Nnode = nTip - 1L),
-                order = 'preorder',
-                class = 'phylo')
+                order = "preorder",
+                class = "phylo")
     }
   }
 }
@@ -342,21 +342,21 @@ as.phylo.integer64 <- function(x, nTip = attr(x, 'nTip'),
 
 #' @rdname TreeNumber
 #' @export
-as.phylo.TreeNumber <- function(x, nTip = attr(x, 'nTip'),
-                                 tipLabels = attr(x, 'tip.label'), ...) {
-  if (is.null(tipLabels)) tipLabels <- paste0('t', seq_len(nTip))
+as.phylo.TreeNumber <- function(x, nTip = attr(x, "nTip"),
+                                 tipLabels = attr(x, "tip.label"), ...) {
+  if (is.null(tipLabels)) tipLabels <- paste0("t", seq_len(nTip))
   edge <- RenumberEdges(num_to_parent(.Int64.to.C(x), nTip),
                         seq_len(nTip + nTip - 2L))
   structure(list(edge = do.call(cbind, edge),
                  tip.label = tipLabels,
                  Nnode = nTip - 1L),
-            order = 'preorder',
-            class = 'phylo')
+            order = "preorder",
+            class = "phylo")
 }
 
 #' @export
 as.integer64.TreeNumber <- function(x, ...) {
-  structure(x[1], class = 'integer64')
+  structure(x[1], class = "integer64")
 }
 
 #' Print `TreeNumber` object
@@ -368,10 +368,10 @@ as.integer64.TreeNumber <- function(x, ...) {
 #'
 #' @export
 print.TreeNumber <- function(x, ...) {
-  nTip <- attr(x, 'nTip')
+  nTip <- attr(x, "nTip")
   cat("Phylogenetic tree number", .PrintedTreeNumber(x), "of",
       .PrintNUnrooted(nTip), "\n",
-      nTip, "tips:", paste0(attr(x, 'tip.label')))
+      nTip, "tips:", paste0(attr(x, "tip.label")))
 }
 
 #' @keywords internal
@@ -382,12 +382,12 @@ print.TreeNumber <- function(x, ...) {
 # x: Object of class `TreeNumber`
 #' @keywords internal
 .PrintedTreeNumber <- function(x) {
-  paste0(structure(x, class = 'integer64'))
+  paste0(structure(x, class = "integer64"))
 }
 
 #' @rdname TreeNumber
 #' @export
-as.MixedBase <- function(x, ...) UseMethod('as.MixedBase')
+as.MixedBase <- function(x, ...) UseMethod("as.MixedBase")
 
 #' @rdname TreeNumber
 #' @export
@@ -405,7 +405,7 @@ as.MixedBase.phylo <- function(x, ...) {
             nTip = nTip,
             tip.label = TipLabels(x),
             binary = TRUE,
-            class = 'MixedBase')
+            class = "MixedBase")
 }
 
 #' @rdname TreeNumber
@@ -416,16 +416,16 @@ as.MixedBase.multiPhylo <- function(x, ...) {
 
 #' @rdname TreeNumber
 #' @export
-as.phylo.MixedBase <- function(x, nTip = attr(x, 'nTip'),
-                               tipLabels = attr(x, 'tip.label'), ...) {
+as.phylo.MixedBase <- function(x, nTip = attr(x, "nTip"),
+                               tipLabels = attr(x, "tip.label"), ...) {
   if (is.null(tipLabels)) {
-    tipLabels <- paste0('t', seq_len(nTip))
+    tipLabels <- paste0("t", seq_len(nTip))
   }
   edge <- RenumberEdges(mixed_base_to_parent(x, nTip),
                         seq_len(nTip + nTip - 2L))
   structure(list(edge = do.call(cbind, edge),
                  tip.label = tipLabels,
                  Nnode = nTip - 1L),
-            order = 'preorder',
-            class = 'phylo')
-}
\ No newline at end of file
+            order = "preorder",
+            class = "phylo")
+}
