@@ -33,8 +33,12 @@ IntegerVector tips_in_splits(RawMatrix splits) {
     n_split = splits.nrow(),
     n_bin = (n_tip % 8 == 0 ? 0 : 1) + (n_tip / 8)
   ;
-  if (n_tip < 1) throw std::out_of_range("nTip < 1");
-  if (n_bin != splits.ncol()) throw std::invalid_argument("nTip does not match split size");
+  if (n_tip < 1) {
+    Rcpp::stop("nTip < 1");
+  }
+  if (n_bin != splits.ncol()) {
+    Rcpp::stop("nTip does not match split size");
+  }
 
   IntegerVector ret(n_split);
   for (int32 i = n_split; i--; ) {
