@@ -1,4 +1,6 @@
 test_that("Consensus() errors", {
+  expect_error(Consensus(trees), regexp = " a list")
+  
   bal8 <- BalancedTree(8)
   oneLeaf <- Consensus(list(DropTip(bal8, 1:7))[c(1, 1, 1)])
   expect_equal(class(oneLeaf), 'phylo')
@@ -8,7 +10,7 @@ test_that("Consensus() errors", {
   expect_warning(expect_true(all.equal(
     Consensus(list(PectinateTree(6), PectinateTree(8))),
     PectinateTree(6)
-  )))
+  )), regexp = "Tree sizes")
 
   halfTree <- CollapseNode(bal8, 10:12)
   expect_equal(Consensus(halfTree), halfTree)
@@ -18,7 +20,7 @@ test_that("Consensus() errors", {
 
 test_that("Consensus()", {
 
-  ApeTest <- function (tr, p = 1) {
+  ApeTest <- function(tr, p = 1) {
     # plot(Consensus(tr))
     # plot(consensus(tr))
     skip_if_not_installed('ape', '5.5.1') # Bug in ape::consensus?
@@ -31,8 +33,8 @@ test_that("Consensus()", {
 
   trees <- list(BalancedTree(8), PectinateTree(8))[c(1, 1, 1, 1, 2, 2, 2)]
   trees <- RenumberTips(trees, trees[[1]])
-  expect_error(Consensus(trees, 2)) # p too hign
-  expect_error(Consensus(trees, 0.2)) # p too low
+  expect_error(Consensus(trees, 2), regexp = "`p`") # p too hign
+  expect_error(Consensus(trees, 0.2), regexp = "`p`") # p too low
 
   ApeTest(trees)
   ApeTest(trees, 0.5)
@@ -41,6 +43,10 @@ test_that("Consensus()", {
   ApeTest(as.phylo(0:2, 8))
   ApeTest(as.phylo(0:250, 8))
   ApeTest(as.phylo(0:250, 80))
+  
+  trees <- list(ape::read.tree(text = "((a, b), (c, d));"),
+                ape::read.tree(text = "((a, c), (b, d));"))
+  expect_equal(Consensus(trees), Preorder(StarTree(letters[1:4])))
 })
 
 test_that('ConsensusWithout() is robust', {
